@@ -33,7 +33,7 @@
  *      All the public types and function declarations for the core
  *	AOLserver.
  *
- *	$Header: /cvsroot/aolserver/aolserver/include/ns.h,v 1.55.2.15 2004/11/22 20:43:04 dossy Exp $
+ *	$Header: /cvsroot/aolserver/aolserver/include/ns.h,v 1.55.2.19 2005/01/18 21:10:07 dossy Exp $
  */
 
 #ifndef NS_H
@@ -41,9 +41,12 @@
 
 #define NS_MAJOR_VERSION	4
 #define NS_MINOR_VERSION	0
-#define NS_RELEASE_SERIAL	9
+#define NS_RELEASE_SERIAL	10
+#define NS_VERSION_NUM          (NS_MAJOR_VERSION * 10000 \
+                                + NS_MINOR_VERSION * 100 \
+                                + NS_RELEASE_SERIAL)
 #define NS_VERSION		"4.0"
-#define NS_PATCH_LEVEL		"4.0.9"
+#define NS_PATCH_LEVEL		"4.0.10"
 
 #define NS_ALPHA_RELEASE	0
 #define NS_BETA_RELEASE		1
@@ -540,6 +543,7 @@ NS_EXTERN void Ns_ClsSet(Ns_Cls *clsPtr, Ns_Conn *conn, void *data);
  */
 
 NS_EXTERN int Ns_Compress(char *buf, int len, Tcl_DString *outPtr, int level);
+NS_EXTERN int Ns_CompressGzip(char *buf, int len, Tcl_DString *outPtr, int level);
 
 /*
  * config.c:
@@ -624,6 +628,7 @@ NS_EXTERN char *Ns_Encrypt(char *pw, char *salt, char iobuf[ ]);
 
 NS_EXTERN int Ns_GetHostByAddr(Ns_DString *dsPtr, char *addr);
 NS_EXTERN int Ns_GetAddrByHost(Ns_DString *dsPtr, char *host);
+NS_EXTERN int Ns_GetAllAddrByHost(Ns_DString *dsPtr, char *host);
 
 /*
  * driver.c:
