@@ -33,7 +33,7 @@
  *	ADP commands.
  */
 
-static const char *RCSID = "@(#) $Header: /cvsroot/aolserver/aolserver/nsd/adpcmds.c,v 1.14 2003/05/21 00:47:29 mpagenva Exp $, compiled: " __DATE__ " " __TIME__;
+static const char *RCSID = "@(#) $Header: /cvsroot/aolserver/aolserver/nsd/adpcmds.c,v 1.14.2.1 2005/01/12 19:11:46 dossy Exp $, compiled: " __DATE__ " " __TIME__;
 
 #include "nsd.h"
 
@@ -747,6 +747,44 @@ NsTclAdpStreamObjCmd(ClientData arg, Tcl_Interp *interp, int objc,
     return TCL_OK;
 }
 
+
+/*
+ *----------------------------------------------------------------------
+ *
+ * NsTclAdpCompressObjCmd --
+ *
+ *	Process the Tcl ns_adp_compress command to enable on-the-fly
+ *	gzip compression of ADP response.
+ *
+ * Results:
+ *	A standard Tcl result.
+ *
+ * Side effects:
+ *	None.
+ *
+ *----------------------------------------------------------------------
+ */
+ 
+int
+NsTclAdpCompressObjCmd(ClientData arg, Tcl_Interp *interp, int objc,
+		     Tcl_Obj **objv)
+{
+    NsInterp *itPtr = arg;
+    int compress = 1;
+
+    if (objc != 1 && objc != 2) {
+	Tcl_WrongNumArgs(interp, 1, objv, "?boolean?");
+        return TCL_ERROR;
+    }
+    if (objc >= 2) {
+        if (Tcl_GetBooleanFromObj(interp, objv[1], &compress) != TCL_OK) {
+            return TCL_ERROR;
+        }
+    }
+    NsAdpCompress(itPtr, compress);
+    return TCL_OK;
+}
+
 
 /*
  *----------------------------------------------------------------------
