@@ -34,7 +34,7 @@
  *
  */
 
-static const char *RCSID = "@(#) $Header: /cvs/root/aolserver/aolserver/aolserver/nsd/driver.c,v 1.17.2.4 2004/06/03 18:02:20 rcrittenden0569 Exp $, compiled: " __DATE__ " " __TIME__;
+static const char *RCSID = "@(#) $Header: /cvsroot/aolserver/aolserver/nsd/driver.c,v 1.17.2.9 2004/09/17 15:30:58 dossy Exp $, compiled: " __DATE__ " " __TIME__;
 
 #include "nsd.h"
 
@@ -90,7 +90,6 @@ static Sock *firstClosePtr; /* First conn ready for graceful close. */
 static int SockRead(Sock *sockPtr);
 static void SockPoll(Sock *sockPtr, Ns_Time *timeoutPtr);
 static void SockTimeout(Sock *sockPtr, Ns_Time *nowPtr, int timeout);
-static void MapServer(NsServer *servPtr, char *proto, char *host);
 static int  SetServer(Sock *sockPtr);
 
 /*
@@ -101,7 +100,7 @@ static Request *firstReqPtr;/* Free list of request structures. */
 static Ns_Mutex reqLock;    /* Lock around request free list. */
 static Sock *firstSockPtr;  /* Free list of Sock structures. */
 static int shutdownPending; /* Flag to indicate shutdown. */
-static int stopped = 1;	    /* Flag to indicate running. */
+static int stopped;	    /* Flag to indicate driver thread stopped. */
 static int nactive;	    /* Active sockets. */
 static Ns_Thread driverThread;/* Running DriverThread. */
 static SOCKET trigPipe[2];  /* Trigger to wakeup DriverThread. */
@@ -111,6 +110,7 @@ static unsigned int nfds;	/* Number of Sock to poll(). */
 static unsigned int maxfds;	/* Max pollfd's in pfds. */ 
 static struct pollfd *pfds; /* Array of pollfds to poll(). */
 static Tcl_HashTable hosts; /* Host header to server table. */
+static ServerMap *defMapPtr;    /* Default server when not found in table. */
 
 
 /*
@@ -155,8 +155,10 @@ NsInitDrivers(void)
 int
 Ns_DriverInit(char *server, char *module, Ns_DriverInitData *init)
 {
-    char *path,*address, *host, *bindaddr, *defproto;
+    char *path,*address, *host, *bindaddr, *defproto, *defserver;
     int i, n, sockwait, defport;
+    ServerMap *mapPtr;
+    Tcl_HashEntry *hPtr;
     Ns_DString ds;
     Ns_Set *set;
     struct in_addr  ia;
@@ -184,6 +186,7 @@ Ns_DriverInit(char *server, char *module, Ns_DriverInitData *init)
 
     host = Ns_ConfigGetValue(path, "hostname");
     bindaddr = address = Ns_ConfigGetValue(path, "address");
+    defserver = Ns_ConfigGetValue(path, "defaultserver");
 
     /*
      * If the listen address was not specified, attempt to determine it
@@ -362,14 +365,41 @@ Ns_DriverInit(char *server, char *module, Ns_DriverInitData *init)
      */
 
     if (server == NULL) {
+        if (defserver == NULL) {
+            Ns_Fatal("%s: virtual servers configured,"
+                    " but %s has no defaultserver defined",
+                    module, path);
+        }
+        defMapPtr = NULL;
 	path = Ns_ConfigGetPath(NULL, module, "servers", NULL);
 	set = Ns_ConfigGetSection(path);
 	for (i = 0; set != NULL && i < Ns_SetSize(set); ++i) {
-	    servPtr = NsGetServer(Ns_SetKey(set, i));
-	    if (servPtr != NULL) {
-		MapServer(servPtr, defproto, Ns_SetValue(set, i));
-	    }
+	    server = Ns_SetKey(set, i);
+	    host = Ns_SetValue(set, i);
+	    servPtr = NsGetServer(server);
+            if (servPtr == NULL) {
+                Ns_Log(Error, "%s: no such server: %s", module, server);
+            } else {
+                hPtr = Tcl_CreateHashEntry(&hosts, host, &n);
+                if (!n) {
+                    Ns_Log(Error, "%s: duplicate host map: %s", module, host);
+                } else {
+                    Ns_DStringVarAppend(&ds, defproto, "://", host, NULL);
+                    mapPtr = ns_malloc(sizeof(ServerMap) + ds.length);
+                    mapPtr->servPtr  = servPtr;
+                    strcpy(mapPtr->location, ds.string);
+                    Ns_DStringTrunc(&ds, 0);
+                    if (defMapPtr == NULL && STREQ(defserver, server)) {
+                        defMapPtr = mapPtr;
+                    }
+                    Tcl_SetHashValue(hPtr, mapPtr);
+                }
+            }
 	}
+        if (defMapPtr == NULL) {
+            Ns_Fatal("%s: default server %s not defined in %s",
+                    module, path);
+        }
     }
 
     return NS_OK;
@@ -1034,45 +1064,6 @@ DriverThread(void *ignored)
     Ns_MutexUnlock(&lock);
 }
 
-
-/*
- *----------------------------------------------------------------------
- *
- * MapServer --
- *
- *	Map a Host header to a virtual server for unbounded drivers.
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	Requests with given Host header will be serviced by given server.
- *
- *----------------------------------------------------------------------
- */
-
-static void
-MapServer(NsServer *servPtr, char *proto, char *host)
-{
-    ServerMap *mapPtr;
-    Tcl_HashEntry *hPtr;
-    Ns_DString ds;
-    int new;
-
-    Ns_DStringInit(&ds);
-    Ns_DStringPrintf(&ds, "%s://%s", proto, host);
-    mapPtr = ns_malloc(sizeof(ServerMap) + ds.length);
-    mapPtr->servPtr  = servPtr;
-    strcpy(mapPtr->location, ds.string);
-    Ns_DStringFree(&ds);
-    hPtr = Tcl_CreateHashEntry(&hosts, host, &new);
-    if (!new) {
-	Ns_Log(Error, "server: duplicate host mapping: %s", host);
-	ns_free(mapPtr);
-    }
-    Tcl_SetHashValue(hPtr, mapPtr);
-}
-
 
 /*
  *----------------------------------------------------------------------
@@ -1093,24 +1084,44 @@ MapServer(NsServer *servPtr, char *proto, char *host)
 static int
 SetServer(Sock *sockPtr)
 {
-    ServerMap *mapPtr;
+    ServerMap *mapPtr = NULL;
     Tcl_HashEntry *hPtr;
     char *host;
+    int status = 1;
 
     sockPtr->servPtr = sockPtr->drvPtr->servPtr;
     sockPtr->location = sockPtr->drvPtr->location;
-    if (sockPtr->servPtr == NULL && sockPtr->reqPtr != NULL) {
+    if (sockPtr->reqPtr) {
 	host = Ns_SetIGet(sockPtr->reqPtr->headers, "Host");
-	if (host != NULL) {
+	if (!host && sockPtr->reqPtr->request->version >= 1.1) {
+	    status = 0;
+	}
+    }
+    if (sockPtr->servPtr == NULL) {
+	if (host) {
 	    hPtr = Tcl_FindHashEntry(&hosts, host);
 	    if (hPtr != NULL) {
 		mapPtr = Tcl_GetHashValue(hPtr);
-		sockPtr->servPtr = mapPtr->servPtr;
-		sockPtr->location = mapPtr->location;
 	    }
 	}
+	if (!mapPtr) {
+	    mapPtr = defMapPtr;
+	}
+	if (mapPtr) {
+	    sockPtr->servPtr = mapPtr->servPtr;
+	    sockPtr->location = mapPtr->location;
+	}
+	if (sockPtr->servPtr == NULL) {
+	    status = 0;
+	}
     }
-    return (sockPtr->servPtr ? 1 : 0);
+
+    if (!status && sockPtr->reqPtr) {
+	ns_free(sockPtr->reqPtr->request->method);
+	sockPtr->reqPtr->request->method = ns_strdup("BAD");
+    }
+    return 1;
+    // return status;
 }
 
 
@@ -1475,18 +1486,18 @@ SockRead(Sock *sockPtr)
 	 */
 
 	if (e == s) {
-            /* Look for a blank line on its own prior to any "real" 
+            /*
+             * Look for a blank line on its own prior to any "real" 
              * data. We eat up to 2 of these before closing the
              * connection.
              */
-            if (bufPtr->length == 2 && e[0] == '\r' && e[1] == '\n') {
-		if (reqPtr->leadblanks++ >= 2) {
-		    reqPtr->leadblanks = 0;
+
+            if (bufPtr->length == 0) {
+		if (++reqPtr->leadblanks > 2) {
 		    return SOCK_ERROR;
 		}
 		reqPtr->woff = reqPtr->roff = 0;
-		reqPtr->leadblanks++;
-		Tcl_DStringSetLength(bufPtr, len - n);
+		Tcl_DStringSetLength(bufPtr, 0);
 		return SOCK_MORE;
             }
 	    reqPtr->coff = reqPtr->roff;
