@@ -33,7 +33,7 @@
  *	AOLserver Ns_Main() startup routine.
  */
 
-static const char *RCSID = "@(#) $Header: /cvs/root/aolserver/aolserver/aolserver/nsd/nsmain.c,v 1.52 2003/11/03 19:23:26 pkhincha Exp $, compiled: " __DATE__ " " __TIME__;
+static const char *RCSID = "@(#) $Header: /cvsroot/aolserver/aolserver/nsd/nsmain.c,v 1.52.2.3 2004/11/15 16:14:40 dossy Exp $, compiled: " __DATE__ " " __TIME__;
 
 #include "nsd.h"
 #ifdef _WIN32
@@ -82,8 +82,8 @@ Ns_Main(int argc, char **argv, Ns_ServerInitProc *initProc)
     Ns_Time 	   timeout;
     char	   buf[PATH_MAX];
 #ifndef _WIN32
-    int		   uid = 0;
-    int		   gid = 0;
+    uid_t	   uid = 0;
+    gid_t	   gid = 0;
     int		   debug = 0;
     int	   	   mode = 0;
     char	  *root = NULL;
@@ -277,6 +277,13 @@ Ns_Main(int argc, char **argv, Ns_ServerInitProc *initProc)
 	gid = Ns_GetUserGid(uarg);
 	if (uid < 0) {
 	    uid = atoi(uarg);
+
+	    /*
+	     * In the case where uarg isn't a username, we set it to NULL,
+	     * causing supplementary groups to be ignored later.
+	     */
+
+	    uarg = NULL;
 	}
 	if (uid == 0) {
 	    Ns_Fatal("nsmain: invalid user '%s'", uarg);
@@ -293,13 +300,11 @@ Ns_Main(int argc, char **argv, Ns_ServerInitProc *initProc)
     }
 
     /*
-     * AOLserver uses select() extensively so adjust the open file
-     * limit to be no greater than FD_SETSIZE on Unix.  It's possible
-     * you could define FD_SETSIZE to a larger value and recompile but
-     * this has not been verified.  Note also that on some platforms
-     * (e.g., Solaris, SGI o32) you're still left with the hardcoded
-     * limit of 255  open streams due to the definition of the FILE
-     * structure with an unsigned char member for the file descriptor.
+     * AOLserver now uses poll() but Tcl and other components may
+     * still use select() which will likely break when fd's exceed
+     * FD_SETSIZE.  We now allow setting the fd limit above FD_SETSIZE,
+     * but do so at your own risk.
+     *
      * Note this limit must be set now to ensure it's inherited by
      * all future threads on certain platforms such as Linux.
      */
@@ -308,9 +313,6 @@ Ns_Main(int argc, char **argv, Ns_ServerInitProc *initProc)
 	Ns_Log(Warning, "nsmain: getrlimit(RLIMIT_NOFILE) failed: '%s'",
 	       strerror(errno));
     } else {
-	if (rl.rlim_max > FD_SETSIZE) {
-	    rl.rlim_max = FD_SETSIZE;
-	}
 	if (rl.rlim_cur != rl.rlim_max) {
     	    rl.rlim_cur = rl.rlim_max;
     	    if (setrlimit(RLIMIT_NOFILE, &rl) != 0) {
@@ -352,7 +354,28 @@ Ns_Main(int argc, char **argv, Ns_ServerInitProc *initProc)
 	    Ns_Fatal("nsmain: server will not run as root; "
 		     "must specify '-u username' parameter");
 	}
-	if (gid != 0 && gid != getgid() && setgid(gid) != 0) {
+	if (gid == 0) {
+	    Ns_Fatal("nsmain: server will not run as gid 0; "
+		     "must specify '-g group' parameter");
+	}
+
+	/*
+	 * Set or clear supplementary groups.
+	 */
+
+	if (uarg != NULL) {
+	    if (initgroups(uarg, gid) != 0) {
+		Ns_Fatal("nsmain: initgroups(%s, %d) failed: '%s'",
+			uarg, gid, strerror(errno));
+	    }
+	} else {
+	    if (setgroups(0, NULL) != 0) {
+		Ns_Fatal("nsmain: setgroups(0, NULL) failed: '%s'",
+			strerror(errno));
+	    }
+	}
+
+	if (gid != getgid() && setgid(gid) != 0) {
 	    Ns_Fatal("nsmain: setgid(%d) failed: '%s'", gid, strerror(errno));
 	}
 	if (setuid(uid) != 0) {
@@ -360,6 +383,20 @@ Ns_Main(int argc, char **argv, Ns_ServerInitProc *initProc)
 	}
     }
 
+#ifdef __linux
+    /*
+     * On Linux, once a process changes uid/gid, the dumpable flag
+     * is cleared, preventing a core file from being written.  On
+     * Linux 2.4+, it can be set again using prctl() so that we can
+     * get core files.
+     */
+     
+    if (prctl(PR_SET_DUMPABLE, 1, 0, 0, 0) < 0) {
+        Ns_Fatal("nsmain: prctl(PR_SET_DUMPABLE) failed: '%s'",
+                strerror(errno));
+    }
+#endif
+
     /*
      * Fork into the background and create a new session if running 
      * in daemon mode.
@@ -521,6 +558,9 @@ Ns_Main(int argc, char **argv, Ns_ServerInitProc *initProc)
 	Ns_Log(Notice, "nsmain: "
 	       "max files: FD_SETSIZE = %d, rl_cur = %d, rl_max = %d",
 	       FD_SETSIZE, rl.rlim_cur, rl.rlim_max);
+	if (rl.rlim_max > FD_SETSIZE) {
+            Ns_Log(Warning, "nsmain: rl_max > FD_SETSIZE");
+	}
     }
 
 #endif
