@@ -34,7 +34,7 @@
  *	Functions that return data to a browser. 
  */
 
-static const char *RCSID = "@(#) $Header: /cvs/root/aolserver/aolserver/aolserver/nsd/return.c,v 1.33.2.1 2004/06/03 18:02:21 rcrittenden0569 Exp $, compiled: " __DATE__ " " __TIME__;
+static const char *RCSID = "@(#) $Header: /cvsroot/aolserver/aolserver/nsd/return.c,v 1.33.2.6 2004/07/19 02:47:10 dossy Exp $, compiled: " __DATE__ " " __TIME__;
 
 #include "nsd.h"
 
@@ -257,10 +257,10 @@ Ns_ConnConstructHeaders(Ns_Conn *conn, Ns_DString *dsPtr)
 	if (nsconf.keepalive.enabled &&
 	    connPtr->headers != NULL &&
 	    connPtr->request != NULL &&
-	    ((connPtr->responseStatus == 200 &&
+	    (( (connPtr->responseStatus >= 200 && connPtr->responseStatus < 300) &&
 	    (lengthHdr != NULL &&
 	    connPtr->responseLength == length) || doChunkEncoding) ||
-	    connPtr->responseStatus == 304) &&
+	    (connPtr->responseStatus == 304 || connPtr->responseStatus == 201 || connPtr->responseStatus == 207) ) &&
 	    (nsconf.keepalive.allmethods == NS_TRUE ||
 	    STREQ(connPtr->request->method, "GET")) &&
 	    (key = Ns_SetIGet(conn->headers, "connection")) != NULL &&
@@ -413,9 +413,8 @@ Ns_ConnCondSetHeaders(Ns_Conn *conn, char *field, char *value)
 void
 Ns_ConnReplaceHeaders(Ns_Conn *conn, Ns_Set *newheaders)
 {
-    newheaders = Ns_SetCopy(newheaders);
     Ns_SetFree(conn->outputheaders);
-    conn->outputheaders = newheaders;
+    conn->outputheaders = Ns_SetCopy(newheaders);
 }
 
 
@@ -470,7 +469,7 @@ Ns_ConnSetRequiredHeaders(Ns_Conn *conn, char *type, int length)
     if (type != NULL) {
     	Ns_ConnSetTypeHeader(conn, type);
     }
-    if (length > 0) {
+    if (length >= 0) {
 	Ns_ConnSetLengthHeader(conn, length);
     }
 
@@ -535,7 +534,7 @@ Ns_ConnSetLengthHeader(Ns_Conn *conn, int length)
  *
  * Ns_ConnSetLastModifiedHeader --
  *
- *	Set the Last-Modified output header. 
+ *	Set the Last-Modified output header if it isn't already set. 
  *
  * Results:
  *	None. 
@@ -552,7 +551,7 @@ Ns_ConnSetLastModifiedHeader(Ns_Conn *conn, time_t *mtime)
     Ns_DString ds;
 
     Ns_DStringInit(&ds);
-    Ns_ConnSetHeaders(conn, "Last-Modified", Ns_HttpTime(&ds, mtime));
+    Ns_ConnCondSetHeaders(conn, "Last-Modified", Ns_HttpTime(&ds, mtime));
     Ns_DStringFree(&ds);
 }
 
@@ -840,14 +839,11 @@ ReturnCharData(Ns_Conn *conn, int status, char *data, int len, char *type,
 
     Ns_ConnSetRequiredHeaders(conn, type, len);
     Ns_ConnQueueHeaders(conn, status);
-    result = NS_OK;
-    if (data != NULL) {
-        if (conn->flags & NS_CONN_SKIPBODY) {
-            data = NULL;
-            len = 0;
-        }
-        result = Ns_WriteConn(conn, data, len);
+    if (conn->flags & NS_CONN_SKIPBODY) {
+        data = NULL;
+        len = 0;
     }
+    result = Ns_WriteConn(conn, data, len);
     if (result == NS_OK) {
         result = Ns_ConnClose(conn);
     }
@@ -1040,15 +1036,15 @@ Ns_ConnReturnUnauthorized(Ns_Conn *conn)
     Ns_DString  ds;
     int	        result;
 
-    if (ReturnRedirect(conn, 401, &result)) {
-	return result;
-    }
     Ns_DStringInit(&ds);
     Ns_DStringVarAppend(&ds, "Basic realm=\"",
 	connPtr->servPtr->opts.realm, "\"", NULL);
     Ns_ConnSetHeaders(conn, "WWW-Authenticate", ds.string);
     Ns_DStringFree(&ds);
 
+    if (ReturnRedirect(conn, 401, &result)) {
+        return result;
+    }
     return Ns_ConnReturnNotice(conn, 401, "Access Denied",
 	"The requested URL cannot be accessed because a "
 	"valid username and password are required.");
