@@ -33,7 +33,7 @@
  * 	Connect Tcl command names to the functions that implement them
  */
 
-static const char *RCSID = "@(#) $Header: /cvsroot/aolserver/aolserver/nsd/tclcmds.c,v 1.38 2003/04/04 13:17:04 mpagenva Exp $, compiled: " __DATE__ " " __TIME__;
+static const char *RCSID = "@(#) $Header: /cvsroot/aolserver/aolserver/nsd/tclcmds.c,v 1.38.2.1 2005/01/12 19:11:46 dossy Exp $, compiled: " __DATE__ " " __TIME__;
 
 #include "nsd.h"
 
@@ -61,6 +61,7 @@ extern Tcl_ObjCmdProc
     NsTclAdpExceptionObjCmd,
     NsTclAdpStreamObjCmd,
     NsTclAdpMimeTypeObjCmd,
+    NsTclAdpCompressObjCmd,
     NsTclChanObjCmd,
     NsTclChmodObjCmd,
     NsTclCondObjCmd,
@@ -509,6 +510,7 @@ static Cmd servCmds[] = {
     {"ns_adp_stream", NULL, NsTclAdpStreamObjCmd},
     {"ns_adp_mime", NULL, NsTclAdpMimeTypeObjCmd},
     {"ns_adp_mimetype", NULL, NsTclAdpMimeTypeObjCmd},
+    {"ns_adp_compress", NULL, NsTclAdpCompressObjCmd},
 
     /*
      * tclvar.c
